package com.ruoyi.postCheck.mapper;

import java.util.List;
import com.ruoyi.postCheck.domain.PostCheckedReport;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 岗检报告管理Mapper接口
 *
 * @author csg
 * @date 2023-12-28
 */
public interface PostCheckedReportMapper extends BaseMapper<PostCheckedReport>
{
    /**
     * 查询岗检报告管理
     *
     * @param id 岗检报告管理主键
     * @return 岗检报告管理
     */
    public PostCheckedReport selectPostCheckedReportById(Long id);

    /**
     * 查询岗检报告管理列表
     *
     * @param postCheckedReport 岗检报告管理
     * @return 岗检报告管理集合
     */
    public List<PostCheckedReport> selectPostCheckedReportList(PostCheckedReport postCheckedReport);

    /**
     * 新增岗检报告管理
     *
     * @param postCheckedReport 岗检报告管理
     * @return 结果
     */
    public int insertPostCheckedReport(PostCheckedReport postCheckedReport);

    /**
     * 修改岗检报告管理
     *
     * @param postCheckedReport 岗检报告管理
     * @return 结果
     */
    public int updatePostCheckedReport(PostCheckedReport postCheckedReport);

    /**
     * 删除岗检报告管理
     *
     * @param id 岗检报告管理主键
     * @return 结果
     */
    public int deletePostCheckedReportById(Long id);

    /**
     * 批量删除岗检报告管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostCheckedReportByIds(Long[] ids);
}
